import esbuild from 'esbuild'
import exec from 'shelljs.exec'

const productionVersion = "1.0"

const build = exec('git log -n 1 --pretty=format:"%h on %as with key %GK"', { async: false }).stdout
const buildDate = new Date().toTimeString()

const banner = `
 ==========================================================================
    __   _____ ______  __                __                _ __
   / /  / ___// __ \\ \\/ /___ _____ _____/ /________ ______(_) /
  / /   \\__ \\/ /_/ /\\  / __ \`/ __ \`/ __  / ___/ __ \`/ ___/ / / 
 / /______/ / ____/ / / /_/ / /_/ / /_/ / /  / /_/ (__  ) / /  
/_____/____/_/     /_/\\__, /\\__, /\\__,_/_/   \\__,_/____/_/_/   
                     /____//____/                              
 A high performance mojang yggdrasil and authlib-injector implmentation
 Version ${productionVersion} ${build}
 Build on ${buildDate}
 
 THIS PROGRAM IS FREE AND OPENSOURCE UNDER THE Anti-996 LICENSE (996.icu)
 Copyright (c) 2022-present, Qumolama.d
 ==========================================================================
`

console.log(banner)
console.log("Creating a production build...")

esbuild.build({
    entryPoints: ['./src/index.js'],
    outfile: './production/lsp-yggdrasil.full.js',
    bundle: true,
    platform: 'node',
    target: 'es2018',
    external: ['./config.js'],
    banner: {
        js: `/*\n${banner}\n*/`
    },
}).then(() => {
    console.log("Done! Enjoy the yggdrasil server as FAST as LSP")
})